use clap::{Arg, ArgAction, ArgMatches, Command};

use crate::commands;
use crate::config::config::Config;

pub fn create() -> Command {
    Command::new("clone")
        .arg(
            Arg::new("remote")
            .required(true)
            .num_args(1)
            .value_name("REMOTE")
            .help("The repository to clone from. See the NEXTSYNC URLS section below for more information on specifying repositories.")
            )
        .arg(
            Arg::new("depth")
            .short('d')
            .long("depth")
            .required(false)
            .num_args(1)
            .help(format!("Depth of the recursive fetch of object properties. This value should be lower when there are a lot of files per directory and higher when there are a lot of subdirectories with fewer files. (Default: {})", crate::services::enumerator::DEFAULT_DEPTH))
            )
        .arg(
            Arg::new("force_insecure")
            .short('f')
            .long("force-insecure")
            .action(ArgAction::SetTrue)
            .help("Force the connection to nextcloud to be in http (not https)")
        )
        .arg(
            Arg::new("directory")
            .required(false)
            .num_args(1)
            .value_name("DIRECTORY")
            )
        .about("Clone a repository into a new directory")
        .after_help("
NEXTSYNC URLS
The following syntaxes may be used:
    - [http[s]://]host.xz/apps/files/?dir=/path/to/repo&fileid=111111
    - [http[s]://]host.xz/path/to/repo
    - [http[s]://]host.xz/remote.php/dav/files/user/path/to/repo
")
}

pub async fn handler(args: &ArgMatches) {
    if let Some(remote) = args.get_one::<String>("remote") {
        commands::clone::exec(
            commands::clone::CloneArgs {
                remote: remote.to_string(),
                depth: args.get_one::<String>("depth").cloned(),
                force_insecure: *args.get_one::<bool>("force_insecure").unwrap(),
            },
            Config::from(args.get_one::<String>("directory")),
        )
        .await;
    }
}
